==> l7-layers-2.9.23.tgz: package/es/tile/tileFactory/rasterDataLayer.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import _inherits from "@babel/runtime/helpers/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

import BaseLayer from "../../core/BaseLayer";
import RasterModel from "../../raster/models/raster";

var RasterTiffLayer = /*#__PURE__*/function (_BaseLayer) {
  _inherits(RasterTiffLayer, _BaseLayer);

  var _super = _createSuper(RasterTiffLayer);

  function RasterTiffLayer() {
    var _this;

    _classCallCheck(this, RasterTiffLayer);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    _defineProperty(_assertThisInitialized(_this), "type", _this.layerType);

    return _this;
  }

  _createClass(RasterTiffLayer, [{
    key: "buildModels",
    value: function buildModels() {
      var _this2 = this;

      var model = this.getModelType();
      this.layerModel = new model(this);
      this.layerModel.initModels(function (models) {
        _this2.models = models;

        _this2.renderLayers();
      });
    }
  }, {
    key: "rebuildModels",
    value: function rebuildModels() {
      var _this3 = this;

      this.layerModel.buildModels(function (models) {
        return _this3.models = models;
      });
    }
  }, {
    key: "getModelType",
    value: function getModelType() {
      return RasterModel;
    }
  }, {
    key: "getConfigSchema",
    value: function getConfigSchema() {
      return {
        properties: {
          opacity: {
            type: 'number',
            minimum: 0,
            maximum: 1
          }
        }
      };
    }
  }, {
    key: "getDefaultConfig",
    value: function getDefaultConfig() {
      return {};
    }
  }]);

  return RasterTiffLayer;
}(BaseLayer);

export { RasterTiffLayer as default };

==> l7-layers-2.9.27.tgz: package/es/tile/tileFactory/rasterDataLayer.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import _inherits from "@babel/runtime/helpers/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

import BaseLayer from "../../core/BaseLayer";
import RasterModel from "../../raster/models/rasterTile";

var RasterTiffLayer = /*#__PURE__*/function (_BaseLayer) {
  _inherits(RasterTiffLayer, _BaseLayer);

  var _super = _createSuper(RasterTiffLayer);

  function RasterTiffLayer() {
    var _this;

    _classCallCheck(this, RasterTiffLayer);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    _defineProperty(_assertThisInitialized(_this), "type", _this.layerType);

    return _this;
  }

  _createClass(RasterTiffLayer, [{
    key: "buildModels",
    value: function buildModels() {
      var _this2 = this;

      var model = this.getModelType();
      this.layerModel = new model(this);
      this.layerModel.initModels(function (models) {
        _this2.models = models;

        _this2.emit('modelLoaded', null);

        _this2.layerService.throttleRenderLayers();
      });
    }
  }, {
    key: "rebuildModels",
    value: function rebuildModels() {
      var _this3 = this;

      this.layerModel.buildModels(function (models) {
        _this3.models = models;

        _this3.emit('modelLoaded', null);
      });
    }
  }, {
    key: "getModelType",
    value: function getModelType() {
      return RasterModel;
    }
  }, {
    key: "getConfigSchema",
    value: function getConfigSchema() {
      return {
        properties: {
          opacity: {
            type: 'number',
            minimum: 0,
            maximum: 1
          }
        }
      };
    }
  }, {
    key: "getDefaultConfig",
    value: function getDefaultConfig() {
      return {};
    }
  }]);

  return RasterTiffLayer;
}(BaseLayer);

export { RasterTiffLayer as default };
